<?php
/*

Plugin Name: Athena Post Expiration

Plugin URI: http://brightthought.co/athena

Description: Set expiration date on various post type or create a expiration profile and assign it to any available post type.

Author: Bright Thought, LLC

Author URI: http://brightthought.co

Version: 1.0.5

Text Domain: athena-post-expiration

Domain Path: /languages

License: GPLv3

License URI: https://www.gnu.org/licenses/gpl.html

*/

if(!defined('ABSPATH')){exit('Permission Denied');}

//Define paths to be used through-out plugin
if(!defined('ATHENA_DIR')){	define('ATHENA_DIR', __DIR__);}
if(!defined('ATHENA_URI')){define('ATHENA_URI', plugin_dir_url(__FILE__));}

if(!defined('ATHENA_OPT')){define ('ATHENA_OPT', 'athena_settings');}
if(!defined('ATHENA_POST')){define('ATHENA_POST', 'athena_active_posts');}
if(!defined('ATHENA_PROFILE')){define('ATHENA_PROFILE', 'athena_active_profiles');}

require_once(ATHENA_DIR . '/model/athena_functions.php');


function Athena_Autoloader( $class ){
	
	if(stristr($class, 'Athena') !== false){
		$folders = array('control', 'model','view');

		$class = strtolower($class);

		foreach($folders as $folder){

			$file = ATHENA_DIR . '/' . $folder . '/' . $class . '.php';
			
			if(file_exists($file)){
				require_once($file);
				break;
			}		
		}
	}
	
}
spl_autoload_register('Athena_Autoloader');


//Start Athena
Athena::init();


function athena_deactivate(){
	global $wpdb, $table_prefix;

	$meta = $wpdb->get_results('SELECT * FROM '.$table_prefix.'postmeta WHERE meta_key LIKE "%athena%"', ARRAY_A);

	$profiles = get_option(ATHENA_PROFILE, false);
	$posts = get_option(ATHENA_POST, false);

	if(!empty($profiles) && is_array($profiles)){

		foreach($profiles as $p){

			wp_clear_scheduled_hook( 'athena_profile_ex_'.$p['id'], array($p['id']) );

			if(isset($p['email']) && $p['email'] === true){
				wp_clear_scheduled_hook( 'athena_profile_email_'.$p['id'], array($p['id']));
			}

		}				

	}

	if(!empty($posts) && is_array($posts)){

		foreach($posts as $p){

			wp_clear_scheduled_hook( 'athena_post_ex_'.$p, array($p) );

		}				

	}

	if(is_array($meta)){

		foreach($meta as $value){

			delete_post_meta($value['post_id'], $value['meta_key']);

		}

	}//end check if variable is array

	$args = array(
		'post_type' => 'athenaprofile',
		'posts_per_page' => -1

	);
	$profiles = get_posts( $args );

	foreach($profiles as $key){

		delete_option('athena_profile_' . $key->ID);
		wp_delete_post( $key->ID );
	}

	delete_option(ATHENA_OPT);
	delete_option(ATHENA_POST);
	delete_option(ATHENA_PROFILE);

}

register_uninstall_hook(__FILE__, 'athena_deactivate' );



