<?php

if(!defined('ABSPATH')){exit('Permission Denied');}

if(!class_exists('Athena_Shortcode')){

	class Athena_Shortcode{

		private static $_instance = null;

		private $_settings;

		private function __construct( $settings ){

			$this->_settings = $settings;

			add_shortcode('athena_expiration', array($this, 'content_expire'));

			$post_type = isset($_GET['post'])?get_post_type($_GET['post']): null;

			if(isset($this->_settings['enable_posttype_'.$post_type]) && $this->_settings['enable_posttype_'.$post_type] == true){
				add_action( 'media_buttons', array($this, 'athena_btn'), 15);
				add_action( 'admin_footer', array($this, 'athena_btn_js' ) );

			}
		}

		public static function init( $settings ){

			if(!self::$_instance instanceof self){

				self::$_instance = new Athena_Shortcode( $settings );

			}

			return self::$_instance;

		}//end init method

		public function content_expire($atts, $content = null){

			$data = shortcode_atts(array(
				'profile' => null,
			), $atts);

			if($data['profile'] !== null && is_numeric($data['profile'])){

				$timestamp = get_post_meta($data['profile'], '_post_expiration_timestamp', true);

			}else{

				return do_shortcode( $content );

			}


			if($timestamp !== false && $timestamp > current_time( 'timestamp', 1)){

				return do_shortcode( $content );

			}


		}//end content_expire method

		public function athena_btn( $content ){

			$html = '<button id="athena-profile-option" class="athena-profile-option-button button"><span class="icon-Athena-icon"></span> Apply Athena Profile</button>';


			$args = array(
				'post_type' => 'athenaprofile',
				'posts_per_page' => -1,
				'meta_key' => '_post_expiration_timestamp',
				'meta_value' => current_time('timestamp', 1),
				'meta_compare' => '>'

			);
			$profiles = get_posts( $args );
			?>

            <div id="athena-profile-modal" style="display:none;">
                <p>
					<?php

					echo '<select id="athena-select-profile">';
					echo '<option value="">Select Profile</option>';
					foreach ($profiles as $value ) {
						echo '<option value="'.$value->ID.'">'.$value->post_title.'</option>';
					}
					echo '</select>';
					?>
                </p>
                <p>
                    <input type="button" id="athena-insert-profile" class="button-primary" value="Insert" />
                </p>
            </div>
			<?php
			echo $html;

		}//end athena_btn method



		public function athena_btn_js( $context ) {

			?>
            <script type="text/javascript">
                jQuery( document ).ready( function() {
                    var optBtn = jQuery( '.athena-profile-option-button' );
                    var jBox = optBtn.jBox( 'Modal', {
                        title: 'Apply Athena Profile Shortcode',
                        position: {
                            x: 'center',
                            y: 'center'
                        },
                        closeButton: 'title',
                        closeOnClick: 'overlay',
                        closeOnEsc: true,
                        content: jQuery( '#athena-profile-modal' ),
                    });

                    optBtn.click(function(e){e.preventDefault()});


                    jQuery( document ).on( 'click', '#athena-insert-profile', function( e ) {
                        e.preventDefault();
                        var profile_id = jQuery( '#athena-select-profile' ).val();

                        if(profile_id.length > 0){

                            var content = tinyMCE.activeEditor.selection.getContent( {format : "html"} );
                            var shortcode = '';

                            if(content.length > 0){
                                shortcode = '[athena_expiration profile="' + profile_id + '"]' + content + '[/athena_expiration]';

                            }else{

                                shortcode = '[athena_expiration profile="' + profile_id + '"][/athena_expiration]';

                            }

                            window.parent.send_to_editor( shortcode );

                            jBox.close();

                        }else{

                            jBox.close();

                        }

                    } );
                } );
            </script>

			<?php

		}//end athena_btn_js method


	}//end class Athena_Shortcode

}//end class_exists conditional