<?php

if(!defined('ABSPATH')){exit('Permission Denied');}

if( !class_exists('Athena_Settings')){

	class Athena_Settings{

		private $_saved;

		private $_post_types = array();

		private static $_instance = null;

		private $_fields;

		private function __construct( $saved, $post_types, $fields ){

			$this->_saved = $saved;
			$this->_post_types = $post_types;
			$this->_fields = $fields;


			add_action( 'admin_menu', array( $this, 'add_athena_page' ));
			add_action('admin_enqueue_scripts', array($this, 'admin_scripts'));


		}//end construct function

		public static function init( $saved, $post_types, $fields ){

			if(!self::$_instance instanceof self){

				self::$_instance = new Athena_Settings( $saved, $post_types, $fields );

			}

			return self::$_instance;

		}//end init function

		public function add_athena_page(){

			add_menu_page(
				'Athena Post Expiration',
				'Athena Post Ex',
				'administrator',
				'athena',
				array($this, 'create_settings_page'),
				'dashicons-sos'
			);

			add_submenu_page(
				'athena',
				'Athena Settings',
				'Settings',
				'administrator',
				'athena'
			);

		}//end add_athena_page method

		public function athena_options(){

			$settings['general'] = '';

			$settings['post-type'] = '';

			$settings['scheduled'] = '';

			return $settings;

		}//end athena_options method


		public function create_settings_page(){
			?>
            <div class="athena-wrapper wrap">
                <h2>Settings - Athena</h2>
                <div class="athena-content-wrapper">
                    <div class="athena-body clearfix">
                        <aside>
                            <div class="athena-aside-header">
                                <img src="<?php echo ATHENA_URI;?>/view/assets/images/Athena-Logo.png" alt="Athena Logo">
                            </div>
                            <ul class="athena-menu">
                                <li><a href="#" data-trigger="general" class="active">General</a></li>

								<?php

								foreach($this->_post_types as $post){
									echo '<li><a href="#" data-trigger="'. $post->name .'">' . $post->label . '</a></li>';
								}
								?>

                                <li><a href="#" data-trigger="scheduled">Scheduled</a></li>
                            </ul>
                        </aside>
                        <main>
                            <form method="post" id="athena-settings" action="" enctype="multipart/form-data" class="clearfix">
                                <div class="athena-save-bar">
                                    <div class="athena-save">
                                        <div class="athena-saving">
                                            <i class="fa fa-spinner fa-spin fa-2x fa-fw"></i>
                                            <span class="sr-only">Saving</span>
                                        </div>
                                        <div class="athena-save-message"></div>
                                    </div>
                                    <input type="submit" value="Save" class="submit">
                                    <input type="reset" value="Reset" class="reset">
                                </div>
                                <div class="athena-form-inner">
                                    <div id="general">
										<?php
										foreach( $this->_fields['general'] as $field){

											if($field['type'] !== 'header'){
												if(isset($this->_saved[$field['id']])){
													$saved = $this->_saved[$field['id']];
												}else{
													$saved = $field['default'];
												}

												new Athena_Fields($field, $saved, $this->_saved);
											}else{

												new Athena_Fields($field, null, $this->_saved);

											}
										}
										?>
                                    </div>
									<?php

									foreach($this->_post_types as $post){
										?>
                                        <div id="<?php echo $post->name; ?>">

											<?php

											foreach($this->post_type_fields($post->name, $post->label) as $field){

												if($field['type'] !== 'header'){
													if(isset($this->_saved[$field['id']])){
														$saved = $this->_saved[$field['id']];
													}else{
														$saved = $field['default'];
													}

													new Athena_Fields($field, $saved, $this->_saved);
												}else{

													new Athena_Fields($field, null, $this->_saved);

												}


											}
											?>
                                        </div>

										<?php
									}
									?>
                                    <div id="scheduled">
										<?php
										foreach( $this->_fields['schedule'] as $field){
											new Athena_Fields( $field, null, $this->_saved );
										}
										?>
                                    </div>
                                </div>
                            </form>
                        </main>
                    </div>
                </div>
            </div>

			<?php
		}//end create_settings_page method

		public function admin_scripts(){

			wp_enqueue_style('athena_settings', ATHENA_URI . 'view/assets/css/athena-settings.css', false);
			wp_enqueue_script('athena-js', ATHENA_URI . 'view/assets/js/athena-admin.js', array('jquery'), '1.0', true);

		}//end admin_scripts method

		private function post_type_fields( $post_type, $title ){

			return array(
				array(
					'type' => 'header',
					'name' => ucfirst($title)
				),
				array(
					'type' => 'checkbox',
					'name' => __('Enable', 'athena-post-expiration'),
					'desc' => __('This will enable Athena Post Expiration options on this particular post type', 'athena-post-expiration'),
					'default' => '',
					'id' => 'enable_posttype_' . $post_type
				),
				array(
					'type' => 'checkbox',
					'name' => __('Auto Apply', 'athena-post-expiration'),
					'desc' => __('This automatically apply expiration to new posts of this post type.', 'athena-post-expiration'),
					'default' => '',
					'id' => 'auto_apply_' . $post_type
				),
				array(
					'type' => 'future_date',
					'name' => __('Default Date', 'athena-post-expiration'),
					'desc' => __('The default amount of time in the future the post will expire.', 'athena-post-expiration'),
					'default' => array('count' => 1, 'type' => 'd'),
					'id' => 'future_date_' . $post_type,
					'times' => 'day'
				),
				array(
					'type' => 'select',
					'name' => __('Expiration Action', 'athena-post-expiration'),
					'desc' => __('Choose the action to take on the expiring post type', 'athena-post-expiration'),
					'id' => 'expire_action_' . $post_type,
					'default' => 'draft',
					'options' => array(
						'delete' => 'Delete',
						'draft' => 'Draft',
						'private' => 'Private',
						'password' => 'Password Protected',
						'category' => 'Change Category'
					),
					'onChange' => true,
					'class' => 'athena-ex-type_' . $post_type
				),
				array(
					'type' => 'text',
					'name' => __('Post Password', 'athena-post-expiration'),
					'desc' => __('Adds a password to the post', 'athena-post-expiration'),
					'id' => 'post_password_' . $post_type,
					'default' => '',
					'activate' => 'athena-ex-type_' . $post_type,
					'select' => 'password',
					'required' => true,
					'max' => 20
				),
				array(
					'type' => 'category',
					'name' => __('Post Category', 'athena-post-expiration'),
					'desc' => __('Select the Categories to assign to the post', 'athena-post-expiration'),
					'id' => 'post_category_' . $post_type,
					'default' => '',
					'activate' => 'athena-ex-type_' . $post_type,
					'select' => 'category',
					'required' => true
				),
				array(
					'type' => 'textarea',
					'name' => __('Append To Footer', 'athena-post-expiration'),
					'desc' => __('Text that will be added to the bottom of the post', 'athena-post-expiration'),
					'id' => 'post_footer_append_' . $post_type,
					'default' => '',
					'legend' => __('<p>%DATETIME% - Displays the date the post expires</p>')
				)

			);

		}//end post_type_fields method

	}//end Athena_Settings class

}//end class_exists